Learn R Programming

PKbioanalysis (version 0.5.0)

.child_to_df: Utility to extract named xml child to dataframe and rename

Description

Utility to extract named xml child to dataframe and rename

Usage

.child_to_df(xmltree, tag)

Arguments

xmltree

xml tree

tag

xml tag to extract