check_chrom_cmpds: Check Matching of Compound and Transitions in chrom_res and...

View source: R/peak_integerate.R

check_chrom_cmpdsR Documentation

Check Matching of Compound and Transitions in chrom_res and method database

Description

Check Matching of Compound and Transitions in chrom_res and method database

Usage

check_chrom_cmpds(chrom_res, method_id)

Arguments

chrom_res

ChromRes object

method_id

Method ID in the method database This is important to give no error before merging quantification results to ensure consistency.

Value

TRUE if all compounds and transitions match, otherwise FALSE


PKbioanalysis documentation built on Jan. 15, 2026, 1:06 a.m.