create_new_study: Create a new study in the database

View source: R/gen_studydesign.R

create_new_studyR Documentation

Create a new study in the database

Description

Create a new study in the database

Usage

create_new_study(df)

Arguments

df

A data frame with one row containing study details: type, title, description, pkstudy (logical), subject_type

Value

A data frame with the created study details including generated id, start_date, and status


PKbioanalysis documentation built on Jan. 15, 2026, 1:06 a.m.