cv: Calculate Coefficient of variation

View source: R/calc.R

cvR Documentation

Calculate Coefficient of variation

Description

Calculate Coefficient of variation

Usage

cv(x, percent = TRUE)

Arguments

x

vector

percent

To return the value as percentage

Details

A simple calculation of the coefficient of variation (CV) is done as the standard deviation divided by the mean. By default, the result is in percentage.

Value

numeric


PKbioanalysis documentation built on Jan. 15, 2026, 1:06 a.m.