dot-parse_tlynx_csv: Parse targetlynx CSV file

.parse_tlynx_csvR Documentation

Parse targetlynx CSV file

Description

Parse targetlynx CSV file

Usage

.parse_tlynx_csv(filepath, first_cmpd)

Arguments

filepath

path to the targetlynx CSV file

first_cmpd

name of the first compound, if not provided it will be extracted from the file

Value

a list of data frames, each containing the data for a compound


PKbioanalysis documentation built on Jan. 15, 2026, 1:06 a.m.