generate_96: Generate 96 well plate

View source: R/plate.R

generate_96R Documentation

Generate 96 well plate

Description

Generate 96 well plate

Usage

generate_96(descr = "", start_row = "A", start_col = 1)

Arguments

descr

plate description.

start_row

A letter corresponding to empty rows in a 96 well plate. Default is A.

start_col

A number indicating a column number to start with, given the start row. Default is 1.

Generate a typical 96 well plate. User need to specify the empty rows which a going to be used across the experiment.

Value

PlateObj

Examples

plate <- generate_96()
plot(plate)

plate <- generate_96("calibration", start_row = "C", start_col = 11)
plot(plate)


PKbioanalysis documentation built on Jan. 15, 2026, 1:06 a.m.