is_integrated: Check if peak was integrated for a specific compound

is_integratedR Documentation

Check if peak was integrated for a specific compound

Description

Check if peak was integrated for a specific compound

Usage

is_integrated(chrom_res, compound_id, sample_id = NULL)

## S4 method for signature 'ChromRes'
is_integrated(chrom_res, compound_id, sample_id = NULL)

## S4 method for signature 'ChromResBase'
is_integrated(chrom_res, compound_id, sample_id = NULL)

Arguments

chrom_res

ChromRes or ChromResBase object

compound_id

Compound ID

sample_id

Sample ID. If NULL, all samples are checked

Value

logical

Examples

## Not run: 
lapply(1:10, \(x) is_integrated(chrom_res, sample_id = 1, compound_id = 1))

## End(Not run)

PKbioanalysis documentation built on Jan. 15, 2026, 1:06 a.m.