register_plate-PlateObj-method: Register a plate This will save the plate to the database

register_plate,PlateObj-methodR Documentation

Register a plate This will save the plate to the database

Description

Register a plate This will save the plate to the database

Usage

## S4 method for signature 'PlateObj'
register_plate(plate)

Arguments

plate

PlateObj object

Value

Registered PlateObj object


PKbioanalysis documentation built on Jan. 15, 2026, 1:06 a.m.