.parse_tlynx_csv: Parse targetlynx CSV file
Description
Parse targetlynx CSV file
Usage
.parse_tlynx_csv(filepath, first_cmpd)
Value
a list of data frames, each containing the data for a compound
Arguments
- filepath
path to the targetlynx CSV file
- first_cmpd
name of the first compound, if not provided it will be extracted from the file