View source: R/peak_integerate.R
| check_chrom_cmpds | R Documentation |
Check Matching of Compound and Transitions in chrom_res and method database
check_chrom_cmpds(chrom_res, method_id)
chrom_res |
ChromRes object |
method_id |
Method ID in the method database This is important to give no error before merging quantification results to ensure consistency. |
TRUE if all compounds and transitions match, otherwise FALSE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.