View source: R/gen_studydesign.R
| create_new_study | R Documentation |
Create a new study in the database
create_new_study(df)
df |
A data frame with one row containing study details: type, title, description, pkstudy (logical), subject_type |
A data frame with the created study details including generated id, start_date, and status
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.