| cv | R Documentation |
Calculate Coefficient of variation
cv(x, percent = TRUE)
x |
vector |
percent |
To return the value as percentage |
A simple calculation of the coefficient of variation (CV) is done as the standard deviation divided by the mean. By default, the result is in percentage.
numeric
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.