| .parse_tlynx_csv | R Documentation |
Parse targetlynx CSV file
.parse_tlynx_csv(filepath, first_cmpd)
filepath |
path to the targetlynx CSV file |
first_cmpd |
name of the first compound, if not provided it will be extracted from the file |
a list of data frames, each containing the data for a compound
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.