View source: R/peak_integerate.R
| extract_peak_bounds | R Documentation |
Extract peak boundaries for a given compound ID
extract_peak_bounds(chrom_res, compound_id)
chrom_res |
ChromRes object |
compound_id |
Compound ID The function automatically priortizes observed peak boundaries (manual integration) over expected ones. If observed boundaries are not available, it falls back to expected boundaries. |
Dataframe with compound_id, min, max
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.