Extract peak boundaries for all samples for a given compound ID
extract_peak_bounds(chrom_res, compound_id, samples_ids = NULL)Dataframe with compound_id, min, max
ChromRes object
Compound ID
Sample IDs. If NULL, all samples will be used The function automatically priortizes observed peak boundaries (manual integration) over expected ones. If observed boundaries are not available, it falls back to expected boundaries.