| read_chrom | R Documentation |
This function reads chromatogram files from a directory and returns a data frame with the chromatogram data.
read_chrom(dir, format = "waters_raw", method)
dir |
directory for chromatraograms |
format |
format of the chromatogram files. Options are "waters_raw" and "mzML". |
method |
LC-MS/MS method ID saved available in the database. |
## Not run:
path <- system.file("extdata", "waters_raw_ex", package="PKbioanalysis")
main <- read_chrom(path, method = 1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.