Read experiment results
read_experiment_results(
x,
drop_prefix = FALSE,
vendor = "targetlynx_xml",
logkey = "Index"
)QuantRes object with the results of the experiment.
path to experiment results. See details
logical. If TRUE, drop the prefix from the sample name
vendor name. Currently only "targetlynx_xml" or "targetlynx_csv" are supported.
character. The column name in the targetlynx CSV file that contains the injection sequence or log key. Default is "Index" which is the default column in targetlynx CSV exports, but it can be customized if the user has a different column name for the injection sequence.
Currently only targetlynx XML or CSV exported files are supported.