update_RT: Manually Update Observed RT for either all compounds, all...

View source: R/peak_integerate.R

update_RTR Documentation

Manually Update Observed RT for either all compounds, all next samples, or single compound and sample

Description

Update RT for either all compounds, all next samples, or single compound and sample

Usage

update_RT(
  chrom_res,
  compound_id,
  sample_id = NULL,
  peak_start,
  peak_end,
  manual = FALSE,
  target = "single",
  force = FALSE
)

Arguments

chrom_res

ChromRes object

compound_id

Compound ID

sample_id

Sample ID

peak_start

Minimum RT value

peak_end

Maximum RT value

manual

Manual update. Default is FALSE

target

Target of update. Options are "single", "all", "all_next"

force

Force update if previous peak exists. Default is FALSE

Details

Only target = "all" will update the expected RT for all compounds.

Examples

## Not run: 
update_RT(chrom_res, compound_id = 1, sample_id = 1, 
          peak_start = 1, peak_end = 2, target = "single")

## End(Not run)

PKbioanalysis documentation built on Jan. 15, 2026, 1:06 a.m.